IdbFactory class abstract

Out factory for opening a database instead of using window.indexedDB

Implementers
Available extensions

Constructors

IdbFactory()

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
idb_shim specific factory name
no setter
pathContext → Context
Path context
no setter
persistent → bool
whether the changes are persistent (i.e. not in memory)
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsDatabaseNames → bool
if getDatabaseNames can be called
no setter
underlyingSembastFactoryOrNull → DatabaseFactory?

Available on IdbFactory, provided by the IdbFactorySembastExtension extension

Cast to Sembast factory
no setter

Methods

cmp(Object first, Object second) → int
compares two values as keys to determine equality and ordering for IndexedDB operations, such as storing and iterating.
debugWrapInLogger({IdbFactoryLoggerType type = IdbFactoryLoggerType.all, int? maxLogCount}) → IdbFactory

Available on IdbFactory, provided by the IdbFactoryLoggerDebugExt extension

Quick logger wrapper, useful in unit test or dev mode.
deleteDatabase(String name, {OnBlockedFunction? onBlocked}) → Future<IdbFactory>
performs the deletion operation asynchronously.
fullPath(String path) → String

Available on IdbFactory, provided by the IdbFactorySandboxExtension extension

full path of a database path
getDatabaseFullPath(String name) → Future<String>
Mainly use for debugging purpose
getDatabaseNames() → Future<List<String>>
list of database names (only available if supportsDatabaseNames returns true).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(String dbName, {int? version, OnUpgradeNeededFunction? onUpgradeNeeded, OnBlockedFunction? onBlocked}) → Future<Database>
requests opening a connection to a database.
openOnDowngradeDelete(String name, {int? version, OnUpgradeNeededFunction? onUpgradeNeeded, OnBlockedFunction? onBlocked}) → Future<Database>

Available on IdbFactory, provided by the IdbFactoryExt extension

Open a database and delete in case of downgrade.
sandbox({required String path}) → IdbFactory

Available on IdbFactory, provided by the IdbFactorySandboxExtension extension

Factory sandboxing.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

supported → bool
Changed to true when a factory is created
no setter