OpenDBRequest class

provides access to the results of requests to open or delete databases

Inheritance

Constructors

OpenDBRequest(Database database, Transaction transaction)
Create an open request on a given database and transaction.

Properties

hashCode → int
The hash code for this object.
no setterinherited
result ↔ Database
The target database.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transaction ↔ Transaction
The associated transaction.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited