VersionChangeEvent class abstract

indicates that the version of the database has changed, as the result of an onupgradeneeded event handler function.

Available extensions

Constructors

VersionChangeEvent()

Properties

currentTarget → Object
Event current target.
no setter
database → Database
idb_shim specific added for convenience
no setter
hashCode → int
The hash code for this object.
no setterinherited
newVersion → int
returns the new version number of the database.
no setter
newVersionOrNull → int?

Available on VersionChangeEvent, provided by the VersionChangeEventExtension extension

The new version, null when the database is being deleted (an event of Database.onVersionChange only, never in onUpgradeNeeded, where VersionChangeEvent.newVersion is always set).
no setter
oldVersion → int
returns the old version number of the database. 0 if created
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → Object
Event target.
no setter
transaction → Transaction
the current transaction
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited