IdbFactoryLogger class abstract

Logger wrapper

Inheritance
Available extensions

Constructors

IdbFactoryLogger()

Properties

factory IdbFactory
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
idb_shim specific
no setterinherited
persistent bool
whether the changes are persistent (i.e. not in memory)
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsDatabaseNames bool
if getDatabaseNames can be called
no setterinherited
type IdbFactoryLoggerType?
getter/setter pair
underlyingSembastFactoryOrNull → DatabaseFactory?

Available on IdbFactory, provided by the IdbFactorySembastExtension extension

Cast to Sembast factory
no setter

Methods

cmp(Object first, Object second) int
compares two values as keys to determine equality and ordering for IndexedDB operations, such as storing and iterating.
inherited
debugWrapInLogger({IdbFactoryLoggerType type = IdbFactoryLoggerType.all, int? maxLogCount}) IdbFactory

Available on IdbFactory, provided by the IdbFactoryLoggerDebugExt extension

Quick logger wrapper, useful in unit test.
deleteDatabase(String name, {OnBlockedFunction? onBlocked}) Future<IdbFactory>
performs the deletion operation asynchronously.
inherited
err(String message, {int? id}) → void
getDatabaseNames() Future<List<String>>
list of database names (only available if supportsDatabaseNames returns true).
inherited
log(String message, {int? id}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(String dbName, {int? version, OnUpgradeNeededFunction? onUpgradeNeeded, OnBlockedFunction? onBlocked}) Future<Database>
requests opening a connection to a database.
inherited
openOnDowngradeDelete(String name, {int? version, OnUpgradeNeededFunction? onUpgradeNeeded, OnBlockedFunction? onBlocked}) Future<Database>

Available on IdbFactory, provided by the IdbFactoryExt extension

Open a database and delete in case of downgrade.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

debugMaxLogCount int?
Allow setting a max number of logs
getter/setter pair