DatabaseIndexNotFoundError class

Index not found.

Inheritance

Constructors

DatabaseIndexNotFoundError(String indexName)
Index not found.

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
Error message.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace ↔ StackTrace?
The stack trace at the point where this error was first thrown.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

indexMessage(String indexName) → String
Message helper.