version property
int?
get
version
The version requested by the blocked open, null when none was given.
Implementation
int? get version;
The version requested by the blocked open, null when none was given.
int? get version;