SdbBoundary<T extends Object> class abstract

Simple boundary definition. include default to true for lower boundary and false for upper boundary.

Implementers

Constructors

SdbBoundary()

Properties

hashCode → int
The hash code for this object.
no setterinherited
include → bool
if true, the boundary will be included in the search result.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → T
Boundary value.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited