inStoresTransaction<T> abstract method
Future<T>
inStoresTransaction<T>(
- List<
SdbStoreRef< stores,SdbKey, SdbValue> > - SdbTransactionMode mode,
- FutureOr<
T> callback()
Run a transaction on multiple stores.
stores is the list of stores to run the transaction on.
mode is the transaction mode, either SdbTransactionMode.readOnly or
SdbTransactionMode.readWrite.
callback is the function to run in the transaction.
Implementation
Future<T> inStoresTransaction<T>(
List<SdbStoreRef> stores,
SdbTransactionMode mode,
FutureOr<T> Function(SdbMultiStoreTransaction txn) callback,
);