SdbDatabaseExtension extension

SimpleDb methods.

on

Properties

openDatabaseOptions SdbOpenDatabaseOptions?

Available on SdbDatabase, provided by the SdbDatabaseExtension extension

Get the openDatabaseOptions used to open the database Could be null, if an existing database is opened without open options without schema information
no setter