SdbFactory class abstract

Abstract SDB Database factory.

Use sdbFactoryWeb on the web, sdbFactoryIo for a default io implementation that uses sembast but prefer sdbFactorySqflite from package idb_sqflite. for a more robust iOS/Android/Desktop implementation. For testing, use sdbFactoryMemory or newSdbFactoryMemory to create a factory in memory

Available extensions

Constructors

SdbFactory()

Properties

hashCode → int
The hash code for this object.
no setterinherited
idbFactory → IdbFactory

Available on SdbFactory, provided by the SdbFactoryExtension extension

Get the underlying idbFactory.
no setter
name → String
Debugging purpose
no setter
pathContext → Context

Available on SdbFactory, provided by the SdbFactorySandboxExtension extension

Path context
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

debugWrapInLogger({SdbFactoryLoggerType type = SdbFactoryLoggerType.all, int? maxLogCount}) → SdbFactory

Available on SdbFactory, provided by the SdbFactoryLoggerExtension extension

Quick logger wrapper, useful in unit test or dev mode.
deleteDatabase(String name) → Future<void>
Delete a database.
inherited
fullPath(String path) → String

Available on SdbFactory, provided by the SdbFactorySandboxExtension extension

full path of a database path
getDatabaseFullPath(String name) → Future<String>
Mainly use for debugging purpose
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openDatabase(String name, {SdbOpenDatabaseOptions? options, int? version, SdbOnVersionChangeCallback? onVersionChange, SdbDatabaseSchema? schema}) → Future<SdbDatabase>
Open a database.
inherited
openDatabaseOnDowngradeDelete(String name, {SdbOpenDatabaseOptions? options, int? version, SdbOnVersionChangeCallback? onVersionChange}) → Future<SdbDatabase>

Available on SdbFactory, provided by the SdbFactoryExtension extension

Open a database, deleting it on downgrade.
sandbox({required String path}) → SdbFactory

Available on SdbFactory, provided by the SdbFactorySandboxExtension extension

Factory sandboxing.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited