SdbFindOptions<K extends SdbKey> class

Common find options, boundaries key

Constructors

SdbFindOptions({SdbBoundaries<K>? boundaries, SdbFilter? filter, int? limit, int? offset, bool? descending})
Common find options

Properties

boundaries → SdbBoundaries<K>?
Optional bounderies, when supported
final
descending → bool?
Descending order
final
filter → SdbFilter?
Optional filter, when supported Warning, will happen in memory once boundaries are applied
final
hashCode → int
The hash code for this object.
no setterinherited
limit → int?
Limit
final
offset → int?
Offset
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({SdbFilter? filter, int? limit, int? offset, bool? descending, SdbBoundaries<K>? boundaries}) → SdbFindOptions<K>
Copy with
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited