SdbIndexRecordRef<K extends SdbKey, V extends SdbValue, I extends SdbIndexKey> class abstract

Index record reference at a given index key. An index key may refer to multiple records.

Available extensions

Constructors

SdbIndexRecordRef()

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → SdbIndexRef<K, V, I>
Index reference.
no setter
indexKey → I
Get index key.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
store → SdbStoreRef<K, V>
Store reference.
no setter

Methods

count(SdbClient client, {SdbFindOptions<I>? options}) → Future<int>

Available on SdbIndexRecordRef<K, V, I>, provided by the SdbIndexRecordRefExtension extension

Count all records with this index key.
delete(SdbClient client, {SdbFindOptions<I>? options}) → Future<void>

Available on SdbIndexRecordRef<K, V, I>, provided by the SdbIndexRecordRefExtension extension

Delete all records with this index key.
findKeys(SdbClient client, {SdbFindOptions<I>? options}) → Future<List<K>>

Available on SdbIndexRecordRef<K, V, I>, provided by the SdbIndexRecordRefExtension extension

Find all records with this index key.
findRecordKeys(SdbClient client, {SdbFindOptions<I>? options}) → Future<List<SdbIndexRecordKey<K, V, I>>>

Available on SdbIndexRecordRef<K, V, I>, provided by the SdbIndexRecordRefExtension extension

Find all records with this index key.
findRecords(SdbClient client, {SdbFindOptions<I>? options}) → Future<List<SdbIndexRecordSnapshot<K, V, I>>>

Available on SdbIndexRecordRef<K, V, I>, provided by the SdbIndexRecordRefExtension extension

Find all records with this index key.
get(SdbClient client) → Future<SdbIndexRecordSnapshot<K, V, I>?>

Available on SdbIndexRecordRef<K, V, I>, provided by the SdbIndexRecordRefExtension extension

Get a single record.
getKey(SdbClient client) → Future<K?>

Available on SdbIndexRecordRef<K, V, I>, provided by the SdbIndexRecordRefExtension extension

Get a single record key.
getValue(SdbClient client) → Future<V?>

Available on SdbIndexRecordRef<K, V, I>, provided by the SdbIndexRecordRefExtension extension

Get a single record value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSnapshot(SdbDatabase db) → Stream<SdbIndexRecordSnapshot<K, V, IK>?>

Available on SdbIndexRecordRef<K, V, IK>, provided by the SdbIndexRecordRefExtensionOnSnapshot extension

Reads the data and set a listener to redo the query on changes, including changes made in other browser tabs.
onSnapshots(SdbDatabase db, {SdbFindOptions<IK>? options}) → Stream<List<SdbIndexRecordSnapshot<K, V, IK>>>

Available on SdbIndexRecordRef<K, V, IK>, provided by the SdbIndexRecordRefExtensionOnSnapshot extension

Reads the data and set a listener to redo the query on changes, including changes made in other browser tabs.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited