SdbIndexRecordSnapshot<K extends SdbKey, V extends SdbValue, I extends SdbIndexKey> class abstract

Index record snapshot.

Inheritance

Constructors

SdbIndexRecordSnapshot()

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → SdbIndexRef<K, V, I>
Index reference.
no setterinherited
indexKey → I
Index key.
no setterinherited
key → K
Primary key.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
store → SdbStoreRef<K, V>
Store reference.
no setterinherited
value → V
Value.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited