SdbIndexRef<K extends SdbKey, V extends SdbValue, I extends SdbIndexKey> class abstract interface

Index reference.

Implementers
Available extensions

Properties

asJoinSource SdbJoinSource<K, V, I>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefJoinSourceExtension extension

This index as a join source, walked in index key order, its index key being the join key.
no setter
asJoinTarget SdbJoinTarget<JK, JV>

Available on SdbIndexRef<JK, JV, I>, provided by the SdbIndexRefJoinTargetExtension extension

This index as a join target, matched on its index key.
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
Index name.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store SdbStoreRef<K, V>
Store reference.
no setter

Methods

count(SdbClient client, {SdbBoundaries<I>? boundaries, SdbFindOptions<I>? options}) Future<int>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefExtension extension

Count records with this index key
delete(SdbClient client, {SdbBoundaries<I>? boundaries, int? offset, int? limit, bool? descending, SdbFindOptions<I>? options}) Future<void>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefExtension extension

Delete records.
findJoinedRecords<JK extends SdbKey, JV extends SdbValue>(SdbClient client, {required SdbJoinTarget<JK, JV> target, SdbFindOptions<I>? options, SdbJoinFindOptions? joinOptions}) Future<List<SdbRecordSnapshot<JK, JV>>>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefJoinExtension extension

See SdbJoinSourceExtension.findJoinedRecords.
findJoinRecords<JK extends SdbKey, JV extends SdbValue>(SdbClient client, {required SdbJoinTarget<JK, JV> target, SdbFindOptions<I>? options, SdbJoinFindOptions? joinOptions}) Future<List<SdbRecordSnapshot<K, V>>>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefJoinExtension extension

See SdbJoinSourceExtension.findJoinRecords.
findJoinRows<JK extends SdbKey, JV extends SdbValue>(SdbClient client, {required SdbJoinTarget<JK, JV> target, SdbFindOptions<I>? options, SdbJoinFindOptions? joinOptions}) Future<List<SdbJoinRow<K, V, JK, JV>>>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefJoinExtension extension

See SdbJoinSourceExtension.findJoinRows.
findRecord(SdbClient client, {SdbBoundaries<I>? boundaries, SdbFilter? filter, int? offset, int? limit, bool? descending, SdbFindOptions<I>? options}) Future<SdbIndexRecordSnapshot<K, V, I>?>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefExtension extension

Find records.
findRecordKey(SdbClient client, {SdbBoundaries<I>? boundaries, SdbFilter? filter, int? offset, bool? descending, SdbFindOptions<I>? options}) Future<SdbIndexRecordKey<K, V, I>?>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefExtension extension

Find first record key.
findRecordKeys(SdbClient client, {SdbBoundaries<I>? boundaries, int? offset, int? limit, SdbFilter? filter, bool? descending, SdbFindOptions<I>? options}) Future<List<SdbIndexRecordKey<K, V, I>>>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefExtension extension

Find record keys.
findRecords(SdbClient client, {SdbBoundaries<I>? boundaries, SdbFilter? filter, int? offset, int? limit, bool? descending, SdbFindOptions<I>? options}) Future<List<SdbIndexRecordSnapshot<K, V, I>>>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefExtension extension

Find records.
iterate(SdbClient client, {SdbTransactionMode? mode, SdbFindOptions<K>? options, required SdbIndexCursorRowHandler<K, V, I> onRow}) Future<void>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefExtension extension

if client is a transaction it must match the transaction mode requiring write mode if the transaction is ready only will fail return true to continue iteration.
joinCount<JK extends SdbKey, JV extends SdbValue>(SdbClient client, {required SdbJoinTarget<JK, JV> target, SdbFindOptions<I>? options, SdbJoinFindOptions? joinOptions}) Future<int>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefJoinExtension extension

See SdbJoinSourceExtension.joinCount.
joinIterate<JK extends SdbKey, JV extends SdbValue>(SdbClient client, {required SdbJoinTarget<JK, JV> target, SdbTransactionMode? mode, SdbFindOptions<I>? options, SdbJoinFindOptions? joinOptions, required SdbJoinRowHandler<K, V, JK, JV> onRow}) Future<void>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefJoinExtension extension

See SdbJoinSourceExtension.joinIterate.
joinIterateJoinedRecords<JK extends SdbKey, JV extends SdbValue>(SdbClient client, {required SdbJoinTarget<JK, JV> target, SdbTransactionMode? mode, SdbFindOptions<I>? options, SdbJoinFindOptions? joinOptions, required SdbJoinRecordHandler<JK, JV> onRecord}) Future<void>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefJoinExtension extension

See SdbJoinSourceExtension.joinIterateJoinedRecords.
joinIterateRecords<JK extends SdbKey, JV extends SdbValue>(SdbClient client, {required SdbJoinTarget<JK, JV> target, SdbTransactionMode? mode, SdbFindOptions<I>? options, SdbJoinFindOptions? joinOptions, required SdbJoinRecordHandler<K, V> onRecord}) Future<void>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefJoinExtension extension

See SdbJoinSourceExtension.joinIterateRecords.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCount(SdbDatabase db, {SdbFindOptions<IK>? options}) Stream<int>

Available on SdbIndexRef<K, V, IK>, provided by the SdbIndexRefExtensionOnSnapshots extension

Reads the count and set a listener to redo the count on changes, including changes made in other browser tabs.
onSnapshots(SdbDatabase db, {SdbFindOptions<IK>? options}) Stream<List<SdbIndexRecordSnapshot<K, V, IK>>>

Available on SdbIndexRef<K, V, IK>, provided by the SdbIndexRefExtensionOnSnapshots extension

Reads the data and set a listener to redo the query on changes, including changes made in other browser tabs.
record(I indexKey) SdbIndexRecordRef<K, V, I>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefExtension extension

Record reference.
schema({required Object keyPath, bool? unique}) SdbIndexSchema

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefSchemaExtension extension

Create store schema, keyPath is String, a List<String> or SdbKeyPath
streamRecords(SdbClient client, {SdbBoundaries<I>? boundaries, SdbFilter? filter, int? offset, int? limit, bool? descending, SdbFindOptions<I>? options}) Stream<SdbIndexRecordSnapshot<K, V, I>>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefExtension extension

Find records.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited