SdbIndexRefJoinSourceExtension<K extends SdbKey, V extends SdbValue, I extends SdbIndexKey> extension

Using an index as a join source.

on

Properties

asJoinSource SdbJoinSource<K, V, I>

Available on SdbIndexRef<K, V, I>, provided by the SdbIndexRefJoinSourceExtension extension

This index as a join source, walked in index key order, its index key being the join key.
no setter