asJoinTarget property
SdbJoinTarget<JK, JV>
get
asJoinTarget
This index as a join target, matched on its index key.
Implementation
SdbJoinTarget<JK, JV> get asJoinTarget => SdbJoinTarget.index(this);
This index as a join target, matched on its index key.
SdbJoinTarget<JK, JV> get asJoinTarget => SdbJoinTarget.index(this);