SdbIndexSchema class

Index schema

Available extensions

Constructors

SdbIndexSchema(SdbIndexRef<SdbKey, SdbValue, SdbIndexKey> ref, SdbKeyPath keyPath, {bool unique = false})
Index schema

Properties

def → SdbIndexSchemaDef
Index schema definition
no setter
hashCode → int
The hash code for this object.
no setterinherited
keyPath → SdbKeyPath
Key paths
final
name → String

Available on SdbIndexSchema, provided by the SdbIndexSchemaExtension extension

Index name
no setter
ref → SdbIndexRef<SdbKey, SdbValue, SdbIndexKey>
Index reference
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unique → bool
Unique
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited