chunkSize property
Rows read per query when the implementation joins natively.
Defaults to sdbJoinIterateChunkSize.
Implementation
final int chunkSize;
Rows read per query when the implementation joins natively.
Defaults to sdbJoinIterateChunkSize.
final int chunkSize;