SdbJoinRow<K extends SdbKey, V extends SdbValue, JK extends SdbKey, JV extends SdbValue> class abstract

A row of a join iteration, see SdbStoreRefJoinExtension.joinIterate and SdbIndexRefJoinExtension.joinIterate.

It holds both sides of the join: the record of the iterated (source) store and the record it references.

Constructors

SdbJoinRow()

Properties

hashCode int
The hash code for this object.
no setterinherited
joinedRecord SdbRecordSnapshot<JK, JV>?
The record joinKey matched.
no setter
joinKey Object?
The key the joined record was looked up with.
no setter
record SdbRecordSnapshot<K, V>
The record of the iterated (source) store.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited