countRecords abstract method
Internal: the number of records options selects, without any join.
Implementation
Future<int> countRecords(SdbClient client, SdbFindOptions<SK>? options);
Internal: the number of records options selects, without any join.
Future<int> countRecords(SdbClient client, SdbFindOptions<SK>? options);