sourceBoundariesOf abstract method

SdbBoundaries<K>? sourceBoundariesOf(
  1. SdbFindOptions<SK>? options
)

Internal: the boundaries to hand to the store scan, null when walking an index (the boundaries then apply to the index key, and only reach the scan as a resolved range).

Implementation

SdbBoundaries<K>? sourceBoundariesOf(SdbFindOptions<SK>? options);