SdbMultiStoreTransaction class abstract

Multi-store transaction.

Implemented types
Available extensions

Constructors

SdbMultiStoreTransaction()

Properties

hashCode int
The hash code for this object.
no setterinherited
mode SdbTransactionMode
current mode for accessing the data in the object stores in the scope of the transaction
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeNames Iterable<String>
Object store names.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
store<K extends SdbKey, V extends SdbValue>(SdbStoreRef<K, V> store) SdbTransactionStoreRef<K, V>

Available on SdbTransaction, provided by the SdbTransactionExtension extension

transaction store.
toString() String
A string representation of this object.
inherited
txnStore<K extends SdbKey, V extends SdbValue>(SdbStoreRef<K, V> store) SdbTransactionStoreRef<K, V>

Available on SdbMultiStoreTransaction, provided by the SdbMultiStoreTransactionExtension extension

Get a transaction store.

Operators

operator ==(Object other) bool
The equality operator.
inherited