SdbOpenDatabaseOptions class abstract

Options for opening a Sdb database.

Constructors

SdbOpenDatabaseOptions({int? version, SdbDatabaseSchema? schema})
Options for opening a Sdb database.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema SdbDatabaseSchema?
The schema of the database.
no setter
version int?
The version of the database.
no setter

Methods

copyWith({int? version, SdbDatabaseSchema? schema}) SdbOpenDatabaseOptions
Copy with new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited