SdbOpenIndexRef<K extends SdbKey, V extends SdbValue, I extends SdbIndexKey> class abstract

Index during open.

Implemented types

Constructors

SdbOpenIndexRef()

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyPath → SdbKeyPath
Key Paths.
no setterinherited
multiEntry → bool
Multi entry
no setterinherited
name → String
Index name.
no setterinherited
ref → SdbIndexRef<K, V, I>
Store reference.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
store → SdbTransactionStoreRef<K, V>
transaction store reference.
no setterinherited
transaction → SdbTransaction
Transaction reference.
no setterinherited
unique → bool
Unique
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited