SdbOpenTransaction class abstract

Open transaction.

Implemented types
Available extensions

Constructors

SdbOpenTransaction()

Properties

db → SdbDatabase
the database connection with which this transaction is associated.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
mode → SdbTransactionMode
current mode for accessing the data in the object stores in the scope of the transaction
no setterinherited
openDatabase → SdbOpenDatabase
Open database.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storeNames → Iterable<String>
Object store names.
no setterinherited

Methods

compatMigrate1To2({List<String>? stores}) → Future<void>

Available on SdbClient, provided by the SdbClientMigrationExtension extension

Null means all stores Need to convert SdbTimestamp format if you created before v2 idb_shim
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
store<K extends SdbKey, V extends SdbValue>(SdbStoreRef<K, V> store) → SdbTransactionStoreRef<K, V>

Available on SdbTransaction, provided by the SdbTransactionExtension extension

transaction store.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited