get method
Get a single record snapshot.
If the record does not exist, the snapshot will have exists set to
false.
Implementation
Future<SdbRecordSnapshot<K, V>?> get(SdbClient client) =>
impl.getImpl(client);
Get a single record snapshot.
If the record does not exist, the snapshot will have exists set to
false.
Future<SdbRecordSnapshot<K, V>?> get(SdbClient client) =>
impl.getImpl(client);