SdbRecordSnapshot<K extends SdbKey, V extends SdbValue> class abstract

Record snapshot.

Implemented types
Available extensions

Constructors

SdbRecordSnapshot()

Properties

hashCode int
The hash code for this object.
no setterinherited
key → K

Available on SdbRecordKey<K, V>, provided by the SdbRecordKeyExt extension

Get the record key
no setter
ref SdbRecordRef<K, V>
Record ref.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store SdbStoreRef<K, V>

Available on SdbRecordKey<K, V>, provided by the SdbRecordKeyExt extension

Get the store
no setter
value → V
Value.
no setter

Methods

cast<RK extends SdbKey, RV extends SdbValue>() SdbRecordSnapshot<RK, RV>
Cast if needed
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited