SdbSingleStoreTransaction<K extends SdbKey, V extends SdbValue> class abstract

Single store transaction.

Implemented types
Available extensions

Constructors

SdbSingleStoreTransaction()

Properties

hashCode int
The hash code for this object.
no setterinherited
mode SdbTransactionMode
current mode for accessing the data in the object stores in the scope of the transaction
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeNames Iterable<String>
Object store names.
no setterinherited
txnStore SdbTransactionStoreRef<K, V>
Transaction store reference.
no setter

Methods

add(V value) Future<K>

Available on SdbSingleStoreTransaction<K, V>, provided by the SdbSingleStoreTransactionExtension extension

Add a record
delete(K key) Future<void>

Available on SdbSingleStoreTransaction<K, V>, provided by the SdbSingleStoreTransactionExtension extension

Delete a record
findRecordKeys({SdbBoundaries<K>? boundaries, SdbFilter? filter, int? offset, int? limit, bool? descending, SdbFindOptions<K>? options}) Future<List<SdbRecordKey<K, V>>>

Available on SdbSingleStoreTransaction<K, V>, provided by the SdbSingleStoreTransactionExtension extension

Find record keys.
findRecords({SdbBoundaries<K>? boundaries, SdbFilter? filter, int? offset, int? limit, bool? descending, SdbFindOptions<K>? options}) Future<List<SdbRecordSnapshot<K, V>>>

Available on SdbSingleStoreTransaction<K, V>, provided by the SdbSingleStoreTransactionExtension extension

Find records.
getRecord(K key) Future<SdbRecordSnapshot<K, V>?>

Available on SdbSingleStoreTransaction<K, V>, provided by the SdbSingleStoreTransactionExtension extension

Get a single record.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(K key, V value) Future<void>

Available on SdbSingleStoreTransaction<K, V>, provided by the SdbSingleStoreTransactionExtension extension

Put a record
store<K extends SdbKey, V extends SdbValue>(SdbStoreRef<K, V> store) SdbTransactionStoreRef<K, V>

Available on SdbTransaction, provided by the SdbTransactionExtension extension

transaction store.
streamRecords({SdbFindOptions<K>? options}) Stream<SdbRecordSnapshot<K, V>>

Available on SdbSingleStoreTransaction<K, V>, provided by the SdbSingleStoreTransactionExtension extension

Find records.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited