SdbStoreRefExtensionOnSnapshots<K extends SdbKey, V extends SdbValue> extension

Snapshots extension on store.

on

Methods

onCount(SdbDatabase db, {SdbFindOptions<K>? options}) Stream<int>

Available on SdbStoreRef<K, V>, provided by the SdbStoreRefExtensionOnSnapshots extension

Reads the count and set a listener to redo the count on changes, including changes made in other browser tabs.
onSnapshots(SdbDatabase db, {SdbFindOptions<K>? options}) Stream<List<SdbRecordSnapshot<K, V>>>

Available on SdbStoreRef<K, V>, provided by the SdbStoreRefExtensionOnSnapshots extension

Reads the data and set a listener to redo the query on changes, including changes made in other browser tabs.