SdbStoreRefJoinSourceExtension<K extends SdbKey, V extends SdbValue> extension

Using a store as a join source.

on

Properties

asJoinSource SdbJoinSource<K, V, K>

Available on SdbStoreRef<K, V>, provided by the SdbStoreRefJoinSourceExtension extension

This store as a join source, walked in primary key order, its primary key being the join key.
no setter

Methods

asJoinSourceAt(String joinKeyPath) SdbJoinSource<K, V, K>

Available on SdbStoreRef<K, V>, provided by the SdbStoreRefJoinSourceExtension extension

This store as a join source, walked in primary key order, the join key being the value at joinKeyPath.