asJoinSource property

SdbJoinSource<K, V, K> get asJoinSource

This store as a join source, walked in primary key order, its primary key being the join key.

That is what a one to many join from the parent side needs; use asJoinSourceAt to read the join key from a field instead.

Implementation

SdbJoinSource<K, V, K> get asJoinSource =>
    _SdbJoinStoreSource<K, V>(this, null);