asJoinSourceAt method
This store as a join source, walked in primary key order, the join key
being the value at joinKeyPath.
joinKeyPath is a field path, dot separated for a nested field.
Implementation
SdbJoinSource<K, V, K> asJoinSourceAt(String joinKeyPath) =>
_SdbJoinStoreSource<K, V>(this, joinKeyPath);