asJoinTarget property
SdbJoinTarget<JK, JV>
get
asJoinTarget
This store as a join target, matched on its primary key.
Implementation
SdbJoinTarget<JK, JV> get asJoinTarget => SdbJoinTarget.store(this);
This store as a join target, matched on its primary key.
SdbJoinTarget<JK, JV> get asJoinTarget => SdbJoinTarget.store(this);