SdbStoreSchema class

Store schema

Available extensions

Constructors

SdbStoreSchema(SdbStoreRef<SdbKey, SdbValue> ref, {SdbKeyPath? keyPath, bool autoIncrement = false, List<SdbIndexSchema> indexes = const []})
Store schema

Properties

autoIncrement → bool
Auto increment
final
hashCode → int
The hash code for this object.
no setterinherited
indexes → List<SdbIndexSchema>
Indexes
final
indexNames → Iterable<String>

Available on SdbStoreSchema, provided by the SdbStoreSchemaExtension extension

Helper
no setter
keyPath → SdbKeyPath?
Key path
final
name → String

Available on SdbStoreSchema, provided by the SdbStoreSchemaExtension extension

Store name
no setter
ref → SdbStoreRef<SdbKey, SdbValue>
Store reference
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited