mode property
SdbTransactionMode
get
mode
current mode for accessing the data in the object stores in the scope of the transaction
Implementation
SdbTransactionMode get mode;
current mode for accessing the data in the object stores in the scope of the transaction
SdbTransactionMode get mode;