SdbVersionChangeEvent class abstract

Event passed to SdbOnVersionChangeCallback.

Constructors

SdbVersionChangeEvent({required SdbOpenDatabase db, required SdbOpenTransaction transaction, required int oldVersion, required int newVersion})
Event passed to SdbOnVersionChangeCallback.
factory

Properties

db → SdbOpenDatabase
The opened database.
no setter
hashCode → int
The hash code for this object.
no setterinherited
newVersion → int
The new version.
no setter
oldVersion → int
The old version, 0 if new
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transaction → SdbOpenTransaction
The opened transaction
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited