IdbCursorRow class abstract

Cursor row.

Inheritance

Constructors

IdbCursorRow(Object key, Object primaryKey, Object value)
Create a cursor row with a key, primaryKey and value.

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Object
Cursor row key.
finalinherited
primaryKey → Object
Cursory row primary key.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Object
Cursor row value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited