IdbKeyCursorRow class

Key cursor row.

Implementers

Constructors

IdbKeyCursorRow(Object key, Object primaryKey)
Create a cursor row with a key, and primaryKey.

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Object
Cursor row key.
final
primaryKey → Object
Cursory row primary key.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited