inStoreTransaction<T, K extends SdbKey, V extends SdbValue> abstract method
Future<T>
inStoreTransaction<T, K extends SdbKey, V extends SdbValue>(
- SdbStoreRef<
K, V> store, - SdbTransactionMode mode,
- FutureOr<
T> callback(- SdbSingleStoreTransaction<
K, V> txn
- SdbSingleStoreTransaction<
Run a transaction on a single store.
store is the store to run the transaction on.
mode is the transaction mode, either SdbTransactionMode.readOnly or
SdbTransactionMode.readWrite.
callback is the function to run in the transaction.
Implementation
Future<T> inStoreTransaction<T, K extends SdbKey, V extends SdbValue>(
SdbStoreRef<K, V> store,
SdbTransactionMode mode,
FutureOr<T> Function(SdbSingleStoreTransaction<K, V> txn) callback,
);