sandbox method
Factory sandboxing.
Every database opened or deleted through the returned factory is
located below path in the original factory.
If the factory is already a sandbox, the tree is sanitized (i.e. never 2 levels of sandboxing).
Works with any SdbFactory implementation (io, memory, web).
Implementation
SdbFactory sandbox({required String path}) =>
sdbFactoryFromIdb(idbFactory.sandbox(path: path));