SdbIndex2Ref<K extends SdbKey, V extends SdbValue, I1 extends SdbIndexKey, I2 extends SdbIndexKey> class
abstract
interface
Index on 2 fields
- Inheritance
-
- Object
- SdbIndexRef<
K, V, (I1, I2)> - SdbIndex2Ref
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Index name.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
store
→ SdbStoreRef<
K, V> -
Store reference.
no setterinherited
Methods
-
lowerBoundary(
I1 value1, I2 value2, {bool? include = true}) → SdbBoundary< (I1, I2)> -
Available on SdbIndex2Ref<
Lower boundaryK, V, I1, I2> , provided by the SdbIndex2RefExtension extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
record2(
I1 index1Key, I2 index2Key) → SdbIndexRecordRef< K, V, (I1, I2)> -
Available on SdbIndex2Ref<
Record reference.K, V, I1, I2> , provided by the SdbIndex2RefExtension extension -
schema2(
String keyPath1, String keyPath2, {bool? unique}) → SdbIndexSchema -
Available on SdbIndex2Ref<
Create store schema, keyPath is String, aK, V, I1, I2> , provided by the SdbIndex2RefSchemaExtension extensionList<String>or SdbKeyPath -
toString(
) → String -
A string representation of this object.
inherited
-
upperBoundary(
I1 value1, I2 value2, {bool? include = false}) → SdbBoundary< (I1, I2)> -
Available on SdbIndex2Ref<
Upper boundaryK, V, I1, I2> , provided by the SdbIndex2RefExtension extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited