Index reference.
Properties
-
asJoinSource
→ SdbJoinSource<
K, V, I> -
Available on SdbIndexRef<
This index as a join source, walked in index key order, its index key being the join key.K, V, I> , provided by the SdbIndexRefJoinSourceExtension extensionno setter -
asJoinTarget
→ SdbJoinTarget<
JK, JV> -
Available on SdbIndexRef<
This index as a join target, matched on its index key.JK, JV, I> , provided by the SdbIndexRefJoinTargetExtension extensionno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Index name.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
store
→ SdbStoreRef<
K, V> -
Store reference.
no setter
Methods
-
count(
SdbClient client, {SdbBoundaries< I> ? boundaries, SdbFindOptions<I> ? options}) → Future<int> -
Available on SdbIndexRef<
Count records with this index keyK, V, I> , provided by the SdbIndexRefExtension extension -
delete(
SdbClient client, {SdbBoundaries< I> ? boundaries, int? offset, int? limit, bool? descending, SdbFindOptions<I> ? options}) → Future<void> -
Available on SdbIndexRef<
Delete records.K, V, I> , provided by the SdbIndexRefExtension extension -
findJoinedRecords<
JK extends SdbKey, JV extends SdbValue> (SdbClient client, {required SdbJoinTarget< JK, JV> target, SdbFindOptions<I> ? options, SdbJoinFindOptions? joinOptions}) → Future<List< SdbRecordSnapshot< >JK, JV> > -
Available on SdbIndexRef<
See SdbJoinSourceExtension.findJoinedRecords.K, V, I> , provided by the SdbIndexRefJoinExtension extension -
findJoinRecords<
JK extends SdbKey, JV extends SdbValue> (SdbClient client, {required SdbJoinTarget< JK, JV> target, SdbFindOptions<I> ? options, SdbJoinFindOptions? joinOptions}) → Future<List< SdbRecordSnapshot< >K, V> > -
Available on SdbIndexRef<
See SdbJoinSourceExtension.findJoinRecords.K, V, I> , provided by the SdbIndexRefJoinExtension extension -
findJoinRows<
JK extends SdbKey, JV extends SdbValue> (SdbClient client, {required SdbJoinTarget< JK, JV> target, SdbFindOptions<I> ? options, SdbJoinFindOptions? joinOptions}) → Future<List< SdbJoinRow< >K, V, JK, JV> > -
Available on SdbIndexRef<
See SdbJoinSourceExtension.findJoinRows.K, V, I> , provided by the SdbIndexRefJoinExtension extension -
findRecord(
SdbClient client, {SdbBoundaries< I> ? boundaries, SdbFilter? filter, int? offset, int? limit, bool? descending, SdbFindOptions<I> ? options}) → Future<SdbIndexRecordSnapshot< K, V, I> ?> -
Available on SdbIndexRef<
Find records.K, V, I> , provided by the SdbIndexRefExtension extension -
findRecordKey(
SdbClient client, {SdbBoundaries< I> ? boundaries, SdbFilter? filter, int? offset, bool? descending, SdbFindOptions<I> ? options}) → Future<SdbIndexRecordKey< K, V, I> ?> -
Available on SdbIndexRef<
Find first record key.K, V, I> , provided by the SdbIndexRefExtension extension -
findRecordKeys(
SdbClient client, {SdbBoundaries< I> ? boundaries, int? offset, int? limit, SdbFilter? filter, bool? descending, SdbFindOptions<I> ? options}) → Future<List< SdbIndexRecordKey< >K, V, I> > -
Available on SdbIndexRef<
Find record keys.K, V, I> , provided by the SdbIndexRefExtension extension -
findRecords(
SdbClient client, {SdbBoundaries< I> ? boundaries, SdbFilter? filter, int? offset, int? limit, bool? descending, SdbFindOptions<I> ? options}) → Future<List< SdbIndexRecordSnapshot< >K, V, I> > -
Available on SdbIndexRef<
Find records.K, V, I> , provided by the SdbIndexRefExtension extension -
iterate(
SdbClient client, {SdbTransactionMode? mode, SdbFindOptions< K> ? options, required SdbIndexCursorRowHandler<K, V, I> onRow}) → Future<void> -
Available on SdbIndexRef<
if client is a transaction it must match the transaction mode requiring write mode if the transaction is ready only will fail return true to continue iteration.K, V, I> , provided by the SdbIndexRefExtension extension -
joinCount<
JK extends SdbKey, JV extends SdbValue> (SdbClient client, {required SdbJoinTarget< JK, JV> target, SdbFindOptions<I> ? options, SdbJoinFindOptions? joinOptions}) → Future<int> -
Available on SdbIndexRef<
See SdbJoinSourceExtension.joinCount.K, V, I> , provided by the SdbIndexRefJoinExtension extension -
joinIterate<
JK extends SdbKey, JV extends SdbValue> (SdbClient client, {required SdbJoinTarget< JK, JV> target, SdbTransactionMode? mode, SdbFindOptions<I> ? options, SdbJoinFindOptions? joinOptions, required SdbJoinRowHandler<K, V, JK, JV> onRow}) → Future<void> -
Available on SdbIndexRef<
See SdbJoinSourceExtension.joinIterate.K, V, I> , provided by the SdbIndexRefJoinExtension extension -
joinIterateJoinedRecords<
JK extends SdbKey, JV extends SdbValue> (SdbClient client, {required SdbJoinTarget< JK, JV> target, SdbTransactionMode? mode, SdbFindOptions<I> ? options, SdbJoinFindOptions? joinOptions, required SdbJoinRecordHandler<JK, JV> onRecord}) → Future<void> -
Available on SdbIndexRef<
See SdbJoinSourceExtension.joinIterateJoinedRecords.K, V, I> , provided by the SdbIndexRefJoinExtension extension -
joinIterateRecords<
JK extends SdbKey, JV extends SdbValue> (SdbClient client, {required SdbJoinTarget< JK, JV> target, SdbTransactionMode? mode, SdbFindOptions<I> ? options, SdbJoinFindOptions? joinOptions, required SdbJoinRecordHandler<K, V> onRecord}) → Future<void> -
Available on SdbIndexRef<
See SdbJoinSourceExtension.joinIterateRecords.K, V, I> , provided by the SdbIndexRefJoinExtension extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onCount(
SdbDatabase db, {SdbFindOptions< IK> ? options}) → Stream<int> -
Available on SdbIndexRef<
Reads the count and set a listener to redo the count on changes, including changes made in other browser tabs.K, V, IK> , provided by the SdbIndexRefExtensionOnSnapshots extension -
onSnapshots(
SdbDatabase db, {SdbFindOptions< IK> ? options}) → Stream<List< SdbIndexRecordSnapshot< >K, V, IK> > -
Available on SdbIndexRef<
Reads the data and set a listener to redo the query on changes, including changes made in other browser tabs.K, V, IK> , provided by the SdbIndexRefExtensionOnSnapshots extension -
record(
I indexKey) → SdbIndexRecordRef< K, V, I> -
Available on SdbIndexRef<
Record reference.K, V, I> , provided by the SdbIndexRefExtension extension -
schema(
{required Object keyPath, bool? unique}) → SdbIndexSchema -
Available on SdbIndexRef<
Create store schema, keyPath is String, aK, V, I> , provided by the SdbIndexRefSchemaExtension extensionList<String>or SdbKeyPath -
streamRecords(
SdbClient client, {SdbBoundaries< I> ? boundaries, SdbFilter? filter, int? offset, int? limit, bool? descending, SdbFindOptions<I> ? options}) → Stream<SdbIndexRecordSnapshot< K, V, I> > -
Available on SdbIndexRef<
Find records.K, V, I> , provided by the SdbIndexRefExtension extension -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited