SdbIndexRefJoinSourceExtension<K extends SdbKey, V extends SdbValue, I extends SdbIndexKey> extension
Using an index as a join source.
- on
-
- SdbIndexRef<
K, V, I>
- SdbIndexRef<
Properties
-
asJoinSource
→ SdbJoinSource<
K, V, I> -
Available on SdbIndexRef<
This index as a join source, walked in index key order, its index key being the join key.K, V, I> , provided by the SdbIndexRefJoinSourceExtension extensionno setter