distinct property
Only expand the first source record of each join key, the records without a join key counting as one group.
False by default. It is what you want when you iterate a store only to reach the records it references.
Implementation
final bool distinct;