joinKeyPath property
String?
get
joinKeyPath
Field path holding the join key, null when the key the iteration is ordered by is the join key.
Always null for an index source: the index key is the join key.
Implementation
String? get joinKeyPath;