sourceBoundariesOf abstract method
Internal: the boundaries to hand to the store scan, null when walking an index (the boundaries then apply to the index key, and only reach the scan as a resolved range).
Implementation
SdbBoundaries<K>? sourceBoundariesOf(SdbFindOptions<SK>? options);