SdbOpenTransaction class abstract

Open transaction.

Implemented types
Available extensions

Constructors

SdbOpenTransaction()

Properties

db SdbOpenDatabase
Compat
no setter
hashCode int
The hash code for this object.
no setterinherited
openDatabase SdbOpenDatabase
Open database.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeNames Iterable<String>
Object store names.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
store<K extends SdbKey, V extends SdbValue>(SdbStoreRef<K, V> store) SdbTransactionStoreRef<K, V>

Available on SdbTransaction, provided by the SdbTransactionExtension extension

transaction store.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited