SdbRecordChange<K extends SdbKey, V extends SdbValue> class abstract

Record change info streamed during StoreRef.onChange.

Handle both add, update and delete

Available extensions

Constructors

SdbRecordChange()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAdd → bool

Available on SdbRecordChange<K, V>, provided by the SdbRecordChangeExtension extension

True if the record was added.
no setter
isDelete → bool

Available on SdbRecordChange<K, V>, provided by the SdbRecordChangeExtension extension

true if the record was deleted.
no setter
isUpdate → bool

Available on SdbRecordChange<K, V>, provided by the SdbRecordChangeExtension extension

True if the record was updated.
no setter
newSnapshot → SdbRecordSnapshot<K, V>?
The new record value, null for record removed
no setter
newValue → V?

Available on SdbRecordChange<K, V>, provided by the SdbRecordChangeExtension extension

The new record value, null for record removed
no setter
oldSnapshot → SdbRecordSnapshot<K, V>?
The previous record snapshot, null for record added.
no setter
oldValue → V?

Available on SdbRecordChange<K, V>, provided by the SdbRecordChangeExtension extension

The previous record value, null for record added.
no setter
ref → SdbRecordRef<K, V>

Available on SdbRecordChange<K, V>, provided by the SdbRecordChangeExtension extension

The record ref (new or old one for delete)
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshot → SdbRecordSnapshot<K, V>

Available on SdbRecordChange<K, V>, provided by the SdbRecordChangeExtension extension

The record snapshot (new or old one for delete)
no setter

Methods

cast<RK extends SdbKey, RV extends SdbValue>() → SdbRecordChange<RK, RV>
Cast if needed
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited