SdbStoreRefExtensionOnSnapshots<K extends SdbKey, V extends SdbValue> extension
Snapshots extension on store.
- on
-
- SdbStoreRef<
K, V>
- SdbStoreRef<
Methods
-
onCount(
SdbDatabase db, {SdbFindOptions< K> ? options}) → Stream<int> -
Available on SdbStoreRef<
Reads the count and set a listener to redo the count on changes, including changes made in other browser tabs.K, V> , provided by the SdbStoreRefExtensionOnSnapshots extension -
onSnapshots(
SdbDatabase db, {SdbFindOptions< K> ? options}) → Stream<List< SdbRecordSnapshot< >K, V> > -
Available on SdbStoreRef<
Reads the data and set a listener to redo the query on changes, including changes made in other browser tabs.K, V> , provided by the SdbStoreRefExtensionOnSnapshots extension