SdbStoreRefJoinSourceExtension<K extends SdbKey, V extends SdbValue> extension
Using a store as a join source.
- on
-
- SdbStoreRef<
K, V>
- SdbStoreRef<
Properties
-
asJoinSource
→ SdbJoinSource<
K, V, K> -
Available on SdbStoreRef<
This store as a join source, walked in primary key order, its primary key being the join key.K, V> , provided by the SdbStoreRefJoinSourceExtension extensionno setter
Methods
-
asJoinSourceAt(
String joinKeyPath) → SdbJoinSource< K, V, K> -
Available on SdbStoreRef<
This store as a join source, walked in primary key order, the join key being the value atK, V> , provided by the SdbStoreRefJoinSourceExtension extensionjoinKeyPath.