SdbTransactionIndexRef<K extends SdbKey, V extends SdbValue, I extends SdbIndexKey> class abstract

Transaction store reference.

Implementers

Constructors

SdbTransactionIndexRef({required SdbIndexRef<K, V, I> index, required SdbTransactionStoreRef<K, V> txnStore})
Create transaction index reference.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
keyPath SdbKeyPath
Key Paths.
no setter
multiEntry bool
Multi entry
no setter
name String
Index name.
no setter
ref SdbIndexRef<K, V, I>
Store reference.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store SdbTransactionStoreRef<K, V>
transaction store reference.
no setter
transaction SdbTransaction
Transaction reference.
no setter
unique bool
Unique
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited